Appstream class abstract final

High-level API for the appstream parser.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

version String
Get the native library version string.
no setter

Static Methods

initialize() → void
Load the shared library and initialize the Dart API DL protocol. Must be called once before any other Appstream method.
parseToSqlite({required String xmlPath, required String dbPath, String language = '', int batchSize = 200, ParseWorkerSpawner? workerSpawner}) Stream<ParseEvent>
Parse an appstream XML file and stream to SQLite.