ComponentEvent class

A component notification received from the C++ parser.

Constructors

ComponentEvent({required String id, required String name, required String summary})
Creates a component event with the given id, name, and summary.

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
Unique AppStream component identifier (e.g. org.example.App).
final
name String
Human-readable display name of the component.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
summary String
One-line summary describing the component.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited