ComponentParsed class

Emitted for each component written to the database.

Inheritance

Constructors

ComponentParsed(ComponentEvent component)
Creates a ComponentParsed event wrapping component.

Properties

component ComponentEvent
The parsed component metadata.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited