ComponentCategoriesCompanion class

Constructors

ComponentCategoriesCompanion({Value<String> componentId = const Value.absent(), Value<int> categoryId = const Value.absent(), Value<int> rowid = const Value.absent()})
const
ComponentCategoriesCompanion.insert({required String componentId, required int categoryId, Value<int> rowid = const Value.absent()})

Properties

categoryId → Value<int>
final
componentId → Value<String>
final
hashCode int
The hash code for this object.
no setterinherited
rowid → Value<int>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Value<String>? componentId, Value<int>? categoryId, Value<int>? rowid}) ComponentCategoriesCompanion
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toColumns(bool nullToAbsent) Map<String, Expression<Object>>
Converts this object into a map of column names to expressions to insert or update.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

custom({Expression<String>? componentId, Expression<int>? categoryId, Expression<int>? rowid}) → Insertable<ComponentCategoryRow>