ComponentIconsCompanion class

Constructors

ComponentIconsCompanion({Value<int> id = const Value.absent(), Value<String> componentId = const Value.absent(), Value<int> iconType = const Value.absent(), Value<String> value = const Value.absent(), Value<int?> width = const Value.absent(), Value<int?> height = const Value.absent(), Value<int?> scale = const Value.absent()})
const
ComponentIconsCompanion.insert({Value<int> id = const Value.absent(), required String componentId, required int iconType, required String value, Value<int?> width = const Value.absent(), Value<int?> height = const Value.absent(), Value<int?> scale = const Value.absent()})

Properties

componentId → Value<String>
final
hashCode int
The hash code for this object.
no setterinherited
height → Value<int?>
final
iconType → Value<int>
final
id → Value<int>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scale → Value<int?>
final
value → Value<String>
final
width → Value<int?>
final

Methods

copyWith({Value<int>? id, Value<String>? componentId, Value<int>? iconType, Value<String>? value, Value<int?>? width, Value<int?>? height, Value<int?>? scale}) ComponentIconsCompanion
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toColumns(bool nullToAbsent) Map<String, Expression<Object>>
Converts this object into a map of column names to expressions to insert or update.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

custom({Expression<int>? id, Expression<String>? componentId, Expression<int>? iconType, Expression<String>? value, Expression<int>? width, Expression<int>? height, Expression<int>? scale}) → Insertable<ComponentIconRow>