ComponentRelationRow class
Methods
-
copyWith({int? id, String? componentId, String? relationKind, String? relationType, Value<String?> value = const Value.absent(), Value<String?> compare = const Value.absent(), Value<String?> version = const Value.absent()})
→ ComponentRelationRow
-
-
copyWithCompanion(ComponentRelationsCompanion data)
→ ComponentRelationRow
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toColumns(bool nullToAbsent)
→ Map<String, Expression<Object>>
-
Converts this object into a map of column names to expressions to insert
or update.
-
toCompanion(bool nullToAbsent)
→ ComponentRelationsCompanion
-
-
toJson({ValueSerializer? serializer})
→ Map<String, dynamic>
-
Converts this object into a representation that can be encoded with
json. The serializer can be used to configure how individual values
will be encoded. By default, DriftRuntimeOptions.defaultSerializer will
be used. See ValueSerializer.defaults for details.
-
toJsonString({ValueSerializer? serializer})
→ String
-
Converts this object into a json representation. The
serializer can be
used to configure how individual values will be encoded. By default,
DriftRuntimeOptions.defaultSerializer will be used. See
ValueSerializer.defaults for details.
inherited
-
toString()
→ String
-
A string representation of this object.
override