ComponentUrlsCompanion class

Constructors

ComponentUrlsCompanion({Value<String> componentId = const Value.absent(), Value<int> urlType = const Value.absent(), Value<String> url = const Value.absent(), Value<int> rowid = const Value.absent()})
const
ComponentUrlsCompanion.insert({required String componentId, required int urlType, required String url, Value<int> rowid = const Value.absent()})

Properties

componentId → Value<String>
final
hashCode int
The hash code for this object.
no setterinherited
rowid → Value<int>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url → Value<String>
final
urlType → Value<int>
final

Methods

copyWith({Value<String>? componentId, Value<int>? urlType, Value<String>? url, Value<int>? rowid}) ComponentUrlsCompanion
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toColumns(bool nullToAbsent) Map<String, Expression<Object>>
Converts this object into a map of column names to expressions to insert or update.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

custom({Expression<String>? componentId, Expression<int>? urlType, Expression<String>? url, Expression<int>? rowid}) → Insertable<ComponentUrlRow>