ContentRatingAttrRow class
Constructors
- ContentRatingAttrRow({required String componentId, required String attrId, required String value})
-
const
-
ContentRatingAttrRow.fromJson(Map<
String, dynamic> json, {ValueSerializer? serializer}) -
factory
Properties
- attrId → String
-
final
- componentId → String
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
final
Methods
-
copyWith(
{String? componentId, String? attrId, String? value}) → ContentRatingAttrRow -
copyWithCompanion(
ContentRatingAttrsCompanion data) → ContentRatingAttrRow -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toColumns(
bool nullToAbsent) → Map< String, Expression< Object> > - Converts this object into a map of column names to expressions to insert or update.
-
toCompanion(
bool nullToAbsent) → ContentRatingAttrsCompanion -
toJson(
{ValueSerializer? serializer}) → Map< String, dynamic> -
Converts this object into a representation that can be encoded with
json. Theserializercan be used to configure how individual values will be encoded. By default,DriftRuntimeOptions.defaultSerializerwill be used. SeeValueSerializer.defaultsfor details. -
toJsonString(
{ValueSerializer? serializer}) → String -
Converts this object into a json representation. The
serializercan be used to configure how individual values will be encoded. By default,DriftRuntimeOptions.defaultSerializerwill be used. SeeValueSerializer.defaultsfor details.inherited -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override