ReleaseIssuesCompanion class

Constructors

ReleaseIssuesCompanion({Value<int> id = const Value.absent(), Value<int> releaseId = const Value.absent(), Value<int?> issueType = const Value.absent(), Value<String?> url = const Value.absent(), Value<String?> value = const Value.absent()})
const
ReleaseIssuesCompanion.insert({Value<int> id = const Value.absent(), required int releaseId, Value<int?> issueType = const Value.absent(), Value<String?> url = const Value.absent(), Value<String?> value = const Value.absent()})

Properties

hashCode int
The hash code for this object.
no setterinherited
id → Value<int>
final
issueType → Value<int?>
final
releaseId → Value<int>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url → Value<String?>
final
value → Value<String?>
final

Methods

copyWith({Value<int>? id, Value<int>? releaseId, Value<int?>? issueType, Value<String?>? url, Value<String?>? value}) ReleaseIssuesCompanion
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toColumns(bool nullToAbsent) Map<String, Expression<Object>>
Converts this object into a map of column names to expressions to insert or update.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

custom({Expression<int>? id, Expression<int>? releaseId, Expression<int>? issueType, Expression<String>? url, Expression<String>? value}) → Insertable<ReleaseIssueRow>