ReleaseRow class

Constructors

ReleaseRow({required int id, required String componentId, int? releaseType, String? version, String? date, String? timestamp, String? dateEol, int? urgency, String? description, String? url})
const
ReleaseRow.fromJson(Map<String, dynamic> json, {ValueSerializer? serializer})
factory

Properties

componentId String
final
date String?
final
dateEol String?
final
description String?
final
hashCode int
The hash code for this object.
no setteroverride
id int
final
releaseType int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp String?
final
urgency int?
final
url String?
final
version String?
final

Methods

copyWith({int? id, String? componentId, Value<int?> releaseType = const Value.absent(), Value<String?> version = const Value.absent(), Value<String?> date = const Value.absent(), Value<String?> timestamp = const Value.absent(), Value<String?> dateEol = const Value.absent(), Value<int?> urgency = const Value.absent(), Value<String?> description = const Value.absent(), Value<String?> url = const Value.absent()}) ReleaseRow
copyWithCompanion(ReleasesCompanion data) ReleaseRow
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toColumns(bool nullToAbsent) Map<String, Expression<Object>>
Converts this object into a map of column names to expressions to insert or update.
toCompanion(bool nullToAbsent) ReleasesCompanion
toJson({ValueSerializer? serializer}) Map<String, dynamic>
Converts this object into a representation that can be encoded with json. The serializer can be used to configure how individual values will be encoded. By default, DriftRuntimeOptions.defaultSerializer will be used. See ValueSerializer.defaults for details.
toJsonString({ValueSerializer? serializer}) String
Converts this object into a json representation. The serializer can be used to configure how individual values will be encoded. By default, DriftRuntimeOptions.defaultSerializer will be used. See ValueSerializer.defaults for details.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override