ReleasesCompanion class

Constructors

ReleasesCompanion({Value<int> id = const Value.absent(), Value<String> componentId = const Value.absent(), Value<int?> releaseType = const Value.absent(), Value<String?> version = const Value.absent(), Value<String?> date = const Value.absent(), Value<String?> timestamp = const Value.absent(), Value<String?> dateEol = const Value.absent(), Value<int?> urgency = const Value.absent(), Value<String?> description = const Value.absent(), Value<String?> url = const Value.absent()})
const
ReleasesCompanion.insert({Value<int> id = const Value.absent(), required String componentId, Value<int?> releaseType = const Value.absent(), Value<String?> version = const Value.absent(), Value<String?> date = const Value.absent(), Value<String?> timestamp = const Value.absent(), Value<String?> dateEol = const Value.absent(), Value<int?> urgency = const Value.absent(), Value<String?> description = const Value.absent(), Value<String?> url = const Value.absent()})

Properties

componentId → Value<String>
final
date → Value<String?>
final
dateEol → Value<String?>
final
description → Value<String?>
final
hashCode int
The hash code for this object.
no setterinherited
id → Value<int>
final
releaseType → Value<int?>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp → Value<String?>
final
urgency → Value<int?>
final
url → Value<String?>
final
version → Value<String?>
final

Methods

copyWith({Value<int>? id, Value<String>? componentId, Value<int?>? releaseType, Value<String?>? version, Value<String?>? date, Value<String?>? timestamp, Value<String?>? dateEol, Value<int?>? urgency, Value<String?>? description, Value<String?>? url}) ReleasesCompanion
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toColumns(bool nullToAbsent) Map<String, Expression<Object>>
Converts this object into a map of column names to expressions to insert or update.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

custom({Expression<int>? id, Expression<String>? componentId, Expression<int>? releaseType, Expression<String>? version, Expression<String>? date, Expression<String>? timestamp, Expression<String>? dateEol, Expression<int>? urgency, Expression<String>? description, Expression<String>? url}) → Insertable<ReleaseRow>