ScreenshotImageRow class

Constructors

ScreenshotImageRow({required int id, required int screenshotId, required String url, String? type, int? width, int? height})
const
ScreenshotImageRow.fromJson(Map<String, dynamic> json, {ValueSerializer? serializer})
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
height int?
final
id int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
screenshotId int
final
type String?
final
url String
final
width int?
final

Methods

copyWith({int? id, int? screenshotId, String? url, Value<String?> type = const Value.absent(), Value<int?> width = const Value.absent(), Value<int?> height = const Value.absent()}) ScreenshotImageRow
copyWithCompanion(ScreenshotImagesCompanion data) ScreenshotImageRow
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toColumns(bool nullToAbsent) Map<String, Expression<Object>>
Converts this object into a map of column names to expressions to insert or update.
toCompanion(bool nullToAbsent) ScreenshotImagesCompanion
toJson({ValueSerializer? serializer}) Map<String, dynamic>
Converts this object into a representation that can be encoded with json. The serializer can be used to configure how individual values will be encoded. By default, DriftRuntimeOptions.defaultSerializer will be used. See ValueSerializer.defaults for details.
toJsonString({ValueSerializer? serializer}) String
Converts this object into a json representation. The serializer can be used to configure how individual values will be encoded. By default, DriftRuntimeOptions.defaultSerializer will be used. See ValueSerializer.defaults for details.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override