ComponentRelationsCompanion class
Constructors
-
ComponentRelationsCompanion({Value<
int> id = const Value.absent(), Value<String> componentId = const Value.absent(), Value<String> relationKind = const Value.absent(), Value<String> relationType = const Value.absent(), Value<String?> value = const Value.absent(), Value<String?> compare = const Value.absent(), Value<String?> version = const Value.absent()}) -
const
-
ComponentRelationsCompanion.insert({Value<
int> id = const Value.absent(), required String componentId, required String relationKind, required String relationType, Value<String?> value = const Value.absent(), Value<String?> compare = const Value.absent(), Value<String?> version = const Value.absent()})
Properties
-
compare
→ Value<
String?> -
final
-
componentId
→ Value<
String> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
id
→ Value<
int> -
final
-
relationKind
→ Value<
String> -
final
-
relationType
→ Value<
String> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
value
→ Value<
String?> -
final
-
version
→ Value<
String?> -
final
Methods
-
copyWith(
{Value< int> ? id, Value<String> ? componentId, Value<String> ? relationKind, Value<String> ? relationType, Value<String?> ? value, Value<String?> ? compare, Value<String?> ? version}) → ComponentRelationsCompanion -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toColumns(
bool nullToAbsent) → Map< String, Expression< Object> > - Converts this object into a map of column names to expressions to insert or update.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited