ReleasesCompanion class
Constructors
-
ReleasesCompanion({Value<int> id = const Value.absent(), Value<String> componentId = const Value.absent(), Value<int?> releaseType = const Value.absent(), Value<String?> version = const Value.absent(), Value<String?> date = const Value.absent(), Value<String?> timestamp = const Value.absent(), Value<String?> dateEol = const Value.absent(), Value<int?> urgency = const Value.absent(), Value<String?> description = const Value.absent(), Value<String?> url = const Value.absent()})
-
const
-
ReleasesCompanion.insert({Value<int> id = const Value.absent(), required String componentId, Value<int?> releaseType = const Value.absent(), Value<String?> version = const Value.absent(), Value<String?> date = const Value.absent(), Value<String?> timestamp = const Value.absent(), Value<String?> dateEol = const Value.absent(), Value<int?> urgency = const Value.absent(), Value<String?> description = const Value.absent(), Value<String?> url = const Value.absent()})
-
Methods
-
copyWith({Value<int>? id, Value<String>? componentId, Value<int?>? releaseType, Value<String?>? version, Value<String?>? date, Value<String?>? timestamp, Value<String?>? dateEol, Value<int?>? urgency, Value<String?>? description, Value<String?>? url})
→ ReleasesCompanion
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toColumns(bool nullToAbsent)
→ Map<String, Expression<Object>>
-
Converts this object into a map of column names to expressions to insert
or update.
-
toString()
→ String
-
A string representation of this object.
override