ScreenshotsCompanion class
Constructors
-
ScreenshotsCompanion({Value<
int> id = const Value.absent(), Value<String> componentId = const Value.absent(), Value<bool> isDefault = const Value.absent(), Value<String?> caption = const Value.absent()}) -
const
-
ScreenshotsCompanion.insert({Value<
int> id = const Value.absent(), required String componentId, Value<bool> isDefault = const Value.absent(), Value<String?> caption = const Value.absent()})
Properties
Methods
-
copyWith(
{Value< int> ? id, Value<String> ? componentId, Value<bool> ? isDefault, Value<String?> ? caption}) → ScreenshotsCompanion -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toColumns(
bool nullToAbsent) → Map< String, Expression< Object> > - Converts this object into a map of column names to expressions to insert or update.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited